==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFSimplifiedLinearOpBaseDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFSIMPLIFIEDOPBASE_DECL_HPP
#define TSFSIMPLIFIEDOPBASE_DECL_HPP

#include "SundanceDefs.hpp"
#include "SundanceOut.hpp"
#include "TSFOpWithBackwardsCompatibleApply.hpp"
#include "TSFVectorDecl.hpp"




namespace TSFExtended
{
using namespace Teuchos;
using namespace Thyra;

/** 
 * SimplifiedLinearOpBase provides a simplified apply() interface
 * in terms of handle classes. Writers of operator subtypes
 * can optionally use this interface to be able to work with handle
 * classes rather than raw pointers and such. 
 */
template <class Scalar> 
class SimplifiedLinearOpBase 
  : public OpWithBackwardsCompatibleApply<Scalar>
{
public:


  /** 
   *
   */
  virtual void applyOp(const Thyra::ETransp M_trans,
    const Vector<Scalar>& in,
    Vector<Scalar> out) const = 0 ;


  /** 
   * generalApply() applies either the operator or the transpose
   * according to the value of the transpose flag. This method is
   * backwards compatible with TSFCore-based code.
   */
  void generalApply(const Thyra::ETransp M_trans,
    const Thyra::VectorBase<Scalar>    &x,
    Thyra::VectorBase<Scalar>* y,
    const Scalar alpha = Teuchos::ScalarTraits<Scalar>::one(),
    const Scalar beta  = Teuchos::ScalarTraits<Scalar>::zero()) const ;

};


/**
 * SimplifiedLinearOpWithSpaces extends SimplifiedLinearOpBase to store
 * the range and domain spaces.
 */
template <class Scalar> 
class SimplifiedLinearOpWithSpaces
  : public SimplifiedLinearOpBase<Scalar>
{
public:
  /** */
  SimplifiedLinearOpWithSpaces(const VectorSpace<Scalar>& domain,
    const VectorSpace<Scalar>& range);

  /** 
   * \brief Return a smart pointer for the range space 
   * for <tt>this</tt> operator.
   */
  RCP< const VectorSpaceBase<Scalar> > range() const ;

  /** \brief Return a smart pointer for the domain space for <tt>this</tt> operator.
   */
  RCP< const VectorSpaceBase<Scalar> > domain() const ;

private:
  VectorSpace<Scalar> range_;
  VectorSpace<Scalar> domain_;
  
};

}

#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFSimplifiedLinearOpBaseDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFSIMPLIFIEDOPBASE_DECL_HPP
#define TSFSIMPLIFIEDOPBASE_DECL_HPP

#include "SundanceDefs.hpp"
#include "SundanceOut.hpp"
#include "TSFOpWithBackwardsCompatibleApply.hpp"
#include "TSFVectorDecl.hpp"




namespace TSFExtended
{
using namespace Teuchos;
using namespace Thyra;

/** 
 * SimplifiedLinearOpBase provides a simplified apply() interface
 * in terms of handle classes. Writers of operator subtypes
 * can optionally use this interface to be able to work with handle
 * classes rather than raw pointers and such. 
 */
template <class Scalar> 
class SimplifiedLinearOpBase 
  : public OpWithBackwardsCompatibleApply<Scalar>
{
public:


  /** 
   *
   */
  virtual void applyOp(const Thyra::EOpTransp M_trans,
    const Vector<Scalar>& in,
    Vector<Scalar> out) const = 0 ;


  /** 
   * generalApply() applies either the operator or the transpose
   * according to the value of the transpose flag. This method is
   * backwards compatible with TSFCore-based code.
   */
  void generalApply(const Thyra::EOpTransp M_trans,
    const Thyra::VectorBase<Scalar>    &x,
    Thyra::VectorBase<Scalar>* y,
    const Scalar alpha = Teuchos::ScalarTraits<Scalar>::one(),
    const Scalar beta  = Teuchos::ScalarTraits<Scalar>::zero()) const ;

};


/**
 * SimplifiedLinearOpWithSpaces extends SimplifiedLinearOpBase to store
 * the range and domain spaces.
 */
template <class Scalar> 
class SimplifiedLinearOpWithSpaces
  : public SimplifiedLinearOpBase<Scalar>
{
public:
  /** */
  SimplifiedLinearOpWithSpaces(const VectorSpace<Scalar>& domain,
    const VectorSpace<Scalar>& range);

  /** 
   * \brief Return a smart pointer for the range space 
   * for <tt>this</tt> operator.
   */
  RCP< const VectorSpaceBase<Scalar> > range() const ;

  /** \brief Return a smart pointer for the domain space for <tt>this</tt> operator.
   */
  RCP< const VectorSpaceBase<Scalar> > domain() const ;

private:
  VectorSpace<Scalar> range_;
  VectorSpace<Scalar> domain_;
  
};

}

#endif
